@@ -1,9 +1,9 @@
+from mc.net.minecraft.gamemode.SurvivalGameMode import SurvivalGameMode
 from mc.net.minecraft.renderer.Tesselator import tesselator
 from mc.net.minecraft.gui.GuiComponent import GuiComponent
 from mc.net.minecraft.gui.ChatScreen import ChatScreen
 from mc.net.minecraft.level.tile.Tiles import tiles
 from mc.net.minecraft.GuiMessage import GuiMessage
-from mc.net.minecraft.User import User
 from pyglet import window, gl
 from random import Random
 import math
@@ -38,43 +38,44 @@ class Gui(GuiComponent):
         health = self.__minecraft.player.health
         prevHealth = self.__minecraft.player.lastHealth
         self.__rand.seed(self.tickCounter * 312871)
-        for i in range(10):
-            n5 = 0
-            if invulnerable != 0:
-                n5 = 1
+        if self.__minecraft.gamemode.canHurtPlayer():
+            for i in range(10):
+                n5 = 0
+                if invulnerable != 0:
+                    n5 = 1
 
-            n4 = self.__scaledWidth / 2 - 91 + (i << 3)
-            n3 = self.__scaledHeight - 32
-            if health <= 4:
-                n3 += self.__rand.randint(0, 1)
+                n4 = self.__scaledWidth / 2 - 91 + (i << 3)
+                n3 = self.__scaledHeight - 32
+                if health <= 4:
+                    n3 += self.__rand.randint(0, 1)
 
-            self.blit(n4, n3, 16 + n5 * 9, 0, 9, 9)
-            if invulnerable != 0:
-                if (i << 1) + 1 < prevHealth:
-                    self.blit(n4, n3, 70, 0, 9, 9)
+                self.blit(n4, n3, 16 + n5 * 9, 0, 9, 9)
+                if invulnerable != 0:
+                    if (i << 1) + 1 < prevHealth:
+                        self.blit(n4, n3, 70, 0, 9, 9)
 
-                if (i << 1) + 1 == prevHealth:
-                    self.blit(n4, n3, 79, 0, 9, 9)
+                    if (i << 1) + 1 == prevHealth:
+                        self.blit(n4, n3, 79, 0, 9, 9)
 
-            if (i << 1) + 1 < health:
-                self.blit(n4, n3, 52, 0, 9, 9)
+                if (i << 1) + 1 < health:
+                    self.blit(n4, n3, 52, 0, 9, 9)
 
-            if (i << 1) + 1 != health:
-                continue
-
-            self.blit(n4, n3, 61, 0, 9, 9)
-
-        if self.__minecraft.player.isUnderWater():
-            n6 = math.ceil((self.__minecraft.player.airSupply - 2) * 10.0 / 300.0)
-            n5 = math.ceil(self.__minecraft.player.airSupply * 10.0 / 300.0) - n6
-            for n4 in range(n6 + n5):
-                if n4 < n6:
-                    self.blit(self.__scaledWidth / 2 - 91 + (n4 << 3),
-                              self.__scaledHeight - 32 - 9, 16, 18, 9, 9)
+                if (i << 1) + 1 != health:
                     continue
 
-                self.blit(self.__scaledWidth / 2 - 91 + (n4 << 3),
-                          self.__scaledHeight - 32 - 9, 25, 18, 9, 9)
+                self.blit(n4, n3, 61, 0, 9, 9)
+
+            if self.__minecraft.player.isUnderWater():
+                n6 = math.ceil((self.__minecraft.player.airSupply - 2) * 10.0 / 300.0)
+                n5 = math.ceil(self.__minecraft.player.airSupply * 10.0 / 300.0) - n6
+                for n4 in range(n6 + n5):
+                    if n4 < n6:
+                        self.blit(self.__scaledWidth / 2 - 91 + (n4 << 3),
+                                  self.__scaledHeight - 32 - 9, 16, 18, 9, 9)
+                        continue
+
+                    self.blit(self.__scaledWidth / 2 - 91 + (n4 << 3),
+                              self.__scaledHeight - 32 - 9, 25, 18, 9, 9)
 
         gl.glDisable(gl.GL_BLEND)
 
@@ -105,7 +106,7 @@ class Gui(GuiComponent):
             tex = self.__minecraft.textures.loadTexture('terrain.png')
             gl.glBindTexture(gl.GL_TEXTURE_2D, tex)
             t.begin()
-            tiles.tiles[tile].render(t, self.__minecraft.level, 0, -2, 0, 0)
+            tiles.tiles[tile].render(t)
             t.end()
             gl.glPopMatrix()
             if self.__minecraft.player.inventory.count[slot] > 1:
@@ -118,12 +119,13 @@ class Gui(GuiComponent):
         if self.__minecraft.options.showFramerate:
             self.__minecraft.font.drawShadow(self.__minecraft.fpsString, 2, 12, 0xFFFFFF)
 
-        score = 'Score: &e' + str(self.__minecraft.player.getScore())
-        self.__minecraft.font.drawShadow(score,
-                                         self.__scaledWidth - self.__minecraft.font.width(score) - 2,
-                                         2, 16777215)
-        self.__minecraft.font.drawShadow('Arrows: ' + str(self.__minecraft.player.arrows),
-                                         self.__scaledWidth // 2 + 8, self.__scaledHeight - 33, 16777215)
+        if isinstance(self.__minecraft.gamemode, SurvivalGameMode):
+            score = 'Score: &e' + str(self.__minecraft.player.getScore())
+            self.__minecraft.font.drawShadow(score,
+                                             self.__scaledWidth - self.__minecraft.font.width(score) - 2,
+                                             2, 16777215)
+            self.__minecraft.font.drawShadow('Arrows: ' + str(self.__minecraft.player.arrows),
+                                             self.__scaledWidth // 2 + 8, self.__scaledHeight - 33, 16777215)
 
         b13 = 10
         z5 = False
@@ -144,6 +146,7 @@ class Gui(GuiComponent):
         if self.__minecraft.ksh[window.key.TAB] and self.__minecraft.networkClient and self.__minecraft.networkClient.isConnected():
             players = self.__minecraft.networkClient.getUsernames()
             gl.glEnable(gl.GL_BLEND)
+            gl.glDisable(gl.GL_TEXTURE_2D)
             gl.glBlendFunc(gl.GL_SRC_ALPHA, gl.GL_ONE_MINUS_SRC_ALPHA)
             gl.glBegin(gl.GL_QUADS)
             gl.glColor4f(0.0, 0.0, 0.0, 0.7)
@@ -154,6 +157,7 @@ class Gui(GuiComponent):
             gl.glVertex2f(screenWidth + 128, screenHeight + 68)
             gl.glEnd()
             gl.glDisable(gl.GL_BLEND)
+            gl.glEnable(gl.GL_TEXTURE_2D)
             string = 'Connected players:'
             self.__minecraft.font.drawShadow(string, screenWidth - self.__minecraft.font.width(string) // 2, screenHeight - 64 - 12, 0xFFFFFF)
 
