@@ -9,11 +9,8 @@ class LogTile(Tile):
         super().__init__(tiles, 17)
         self.tex = 20
 
-    def getResourceCount(self):
+    def resourceCount(self):
         return math.floor(3 * random.random()) + 3
 
-    def getId(self):
-        return self.tiles.wood.id
-
     def _getTexture(self, face):
         return 21 if face == 1 else (21 if face == 0 else 20)
