@@ -3,7 +3,4 @@ from mc.net.minecraft.level.tile.Tile import Tile
 class StoneTile(Tile):
 
     def __init__(self, tiles, id_, tex):
-        super().__init__(tiles, 1, 1)
-
-    def getId(self):
-        return self.tiles.stoneBrick.id
+        super().__init__(tiles, id_, tex)
